# weight functions
uw.hard <- function(x, b=1.7) {
  ((abs( x-median(x) ) < mad(x)*b))*1
}
  
ww <- function(z, b) {
  pmin(1,b/abs(z))
}

## Scores for mu and alpha
sB1 <- function(y,mu,alpha,q=1-1e-9,eps=.Machine$double.eps^2) {
  n <- length(y)
  z <- .Fortran("sB1",
        as.double(y),
        as.integer(n),                
        as.double(mu),
        as.double(alpha),
        Z=mat.or.vec(n,2),
        as.integer(n),
        as.double(eps),
        PACKAGE = "robustnegbin")
  return(z$Z)
}
  
EqAlpha <- function(alpha, y, munix, ind, TabAab,len) {
  # M equation for alpha; A, a and b are provided in TabAab; interpolation using FT.itp.Aab
  mualpunix <- cbind(munix, rep(alpha, len))
  Aabunix <- apply(mualpunix, 1, FT.itp.Aab, TabAab=TabAab, verbose=FALSE) # if out of table, brings to the edge 
  n <- length(y) 
  Eq3 <- 0
  for (i in 1:n) {
    iii <- ind[i]
    mui <- munix[iii]
    b <- Aabunix[[iii]]$b
    Ax <- Aabunix[[iii]]$A
    ax <- Aabunix[[iii]]$a
    Sx <- sB1(y[i], mui, alpha)
    wxi  <- uw(Ax %*% (t(Sx) - ax), b)
    Eq3  <- Eq3 + wxi * (Sx[2] - ax[2])
  }
  Eq3
} 

MestimateAlpha <- function(x, y, Beta, alp.low, alp.up, TabAab, tol, maxit, nint,verbose=FALSE, Fortran=FALSE) {
  Table <- robustnegbin::M_Table_80
  alpha1 <- Table$alpha1
  alpha2 <- Table$alpha2
# Solves equation for alpha; uses FT.itp.Aab: interpolation in TabAab
  beta11 <- Beta[1]  # slope
  beta21 <- Beta[2]  # intercept
# use unique x
  ind <- integer()
  m <- length(y)
  x <- as.vector(x)
  unix <- unique(x)
  len <- length(unix)
  for (i in 1:m) {
    ind[i] <- which(unix == x[i])
  }
  etaunix <- unix * beta11 + beta21
  munix   <- inv.Link(etaunix)
  reg <- if (Fortran) {
    RgFlEq3.f(cc=0, lower=alp.low, upper=alp.up, nint, tol=tol, maxit=maxit, y=y, munix=munix, ind=ind, TabAab=TabAab, l=len, weix=rep(1,m), verbose)
  } else {
    regfal(f=EqAlpha, cc=0, lower=alp.low, upper=alp.up, nint=nint, tol=tol, maxit=maxit, y=y, munix=munix, ind=ind, TabAab=TabAab, len=len)
  }
  alpha0  <- reg$solution
  if (is.null(alpha0)) {
    fmin <- EqAlpha(alpha=alp.low, y=y, munix=munix, ind=ind, TabAab=TabAab, len=len)
    fmax <- EqAlpha(alpha=alp.up, y=y, munix=munix, ind=ind, TabAab=TabAab, len=len)
    if (abs(fmin) < abs(fmax)) {
      alpha0 <- alp.low
    } else {
      alpha0 <- alpha1
      reg$solution <- NULL
      warning("In M-Estimate: solution alpha out of limits (alpha1,alpha2)")
    }
  }
  if (verbose==TRUE)
    cat("alpha0:",alpha0,"\n")
  list(alpha0=alpha0)
}

FT.itp.Aab <- function(mual, TabAab, verbose=TRUE) {
# interpolates in table TabAab
  alpha1 <- TabAab$alpha1
  alpha2 <- TabAab$alpha2
  mu1 <- TabAab$mu1
  mu2 <- TabAab$mu2
  ka <- TabAab$ka
  km <- TabAab$km
  alg <- seq(from=alpha1, to=alpha2, length=ka)
  mug <- seq(from=mu1, to=mu2, length=km)
  if (mual[2] <= alpha1) {
    l1 <- 1
    l2 <- 1
    if (verbose)
      cat("alpha <= lower limit:", mual[2], "\n")
  }
  if (mual[2] >= alpha2) {
    l1 <- ka
    l2 <- ka
    if (verbose)
      cat("alpha >= upper limit:", mual[2], "\n")
  }
  if (alpha1 < mual[2] & mual[2] < alpha2) {
    l1 <- as.integer((ka-1)*(mual[2] - alpha1)/(alpha2 - alpha1)) + 1
    l2  <- l1+1
  }
  if (mual[1] <= mu1) {
    m1 <- 1
    m2 <- 1
    if (verbose) cat("mu <= lower limit:", mual[1], "\n")
  }
  if (mual[1] >= mu2) {
    m1 <- km
    m2 <- km
    if (verbose) cat("mu >= upper limit:", mual[1], "\n")
  }
  if (mu1 < mual[1] & mual[1] < mu2) {   
    m1 <- as.integer((km-1)*(mual[1] - mu1)/(mu2 - mu1)) + 1
    m2 <- m1+1
  }
  b <- FT.itp.1(mual, F=TabAab$Tabb, l1, l2, m1, m2, alg, mug)
  A11 <- FT.itp.1(mual, F=TabAab$TabA11, l1, l2, m1, m2, alg, mug)
  A12 <- FT.itp.1(mual, F=TabAab$TabA12, l1, l2, m1, m2, alg, mug)
  A21 <- FT.itp.1(mual, F=TabAab$TabA21, l1, l2, m1, m2, alg, mug)
  A22 <- FT.itp.1(mual, F=TabAab$TabA22, l1, l2, m1, m2, alg, mug)
  a1 <- FT.itp.1(mual, F=TabAab$Taba1, l1, l2, m1, m2, alg, mug)
  a2 <- FT.itp.1(mual, F=TabAab$Taba2, l1, l2, m1, m2, alg, mug)
  A <- matrix(c(A11, A12, A21, A22), ncol=2, byrow=TRUE)
  a <- c(a1, a2)
  list(b=b, A=A, a=a)
}

FT.itp.1 <- function(mual, F, l1, l2, m1, m2, alg, mug) {
# Auxiliary: interpolates values of Table[alpha,mu](=F) over the given grid 
  f11 <- F[l1,m1]
  f21 <- F[l2,m1]
  f12 <- F[l1,m2]
  f22 <- F[l2,m2]
  x <- mual[2]
  y <- mual[1]
  x1 <- alg[l1]
  x2 <- alg[l2]
  y1 <- mug[m1]
  y2 <- mug[m2]
  d <- (x2-x1)*(y2-y1)
  inter <- f11*(x2-x)*(y2-y) + f21*(x-x1)*(y2-y) + f12*(x2-x)*(y-y1) + f22*(x-x1)*(y-y1)
  if (d!=0)
    inter <- inter/d
  if (l1 == l2 & m1 != m2)
    inter <- f11 + (f12 - f11)/(y2 - y1)*(y - y1)
  if (l1 != l2 & m1 == m2)
    inter <- f11 + (f21 - f11)/(x2 - x1)*(x - x1)
  if (l1 == l2 & m1 == m2)
    inter <- f11
  inter
}

#------------------------------------------------------------------------------

regfal <- function(f, cc, lower, upper, nint=50, tol=0.001, maxit=20, ...) {
# Regula falsi to solve f(x)=cc in the interval [lower,upper]
  as <- seq(from=lower, to=upper, length=nint)
  ck <- NULL
  nit <- 0
  i <- 0
  while (i < (nint-1)) {
    i <- i+1
    fa <- f(as[i], ...)-cc
    fb <- f(as[i+1], ...)-cc
# cat(i,as[i],as[i+1],fa,fb,"\n")
    if (fa*fb <= 0) break
  }
  if (i==(nint-1) & fa*fb>0) {
    cat("no solution ", "i=", i, "\n")
    return(list(solution=ck,nit=-1))
  }
  ak <- as[i]
  bk <- as[i+1]
  fa <- f(ak, ...)-cc
  fb <- f(bk, ...)-cc
  nit <- 0
  conv <- FALSE
  while (!conv) {
    fak <- f(ak, ...)-cc
    fbk <- f(bk, ...)-cc
    ck <- ak-(ak-bk)/(fak-fbk)*fak
    if (is.nan(ck)) {
      cat("solution non assigned \n")
      return(list(solution=NULL,nit=nit))
    }
    fck <- f(ck, ...)-cc
    if (fak*fck > 0)
      ak <- ck
    else
      bk <- ck
    conv <- max(abs(fck)) < tol
# cat(nit,ak,bk,ck,fak,fbk,fck,"\n")
    nit <- nit+1
    if (nit==maxit)
      break
  }
  return(list(solution=ck,nit=nit))
}

RgFlEq3.f <- function(cc,lower,upper,nint,tol,maxit,y,munix,ind,TabAab,l,weix,verbose=TRUE) #,hpunix
{
      n      <- length(y)
      alpha1 <- TabAab$alpha1 
      alpha2 <- TabAab$alpha2
      mu1    <- TabAab$mu1
      mu2    <- TabAab$mu2
      ka     <- TabAab$ka
      km     <- TabAab$km
      alg    <- seq(from=alpha1,to=alpha2,length=ka)
      mug    <- seq(from=mu1,   to=mu2,   length=km)
      mwrn   <- verbose*1

   z <- .Fortran("RGFLEQ3",
        as.double(cc),as.double(lower),as.double(upper),as.integer(nint),
        as.double(tol),as.integer(maxit),as.double(y),as.double(munix),
        as.integer(ind),as.integer(n),as.integer(l),as.double(alpha1),
        as.double(alpha2),as.double(mu1),as.double(mu2),as.double(alg),
        as.integer(ka),as.double(mug),as.integer(km),
        as.matrix(TabAab$Tabb),as.matrix(TabAab$TabA11),as.matrix(TabAab$TabA12),
        as.matrix(TabAab$TabA21),as.matrix(TabAab$TabA22),as.matrix(TabAab$Taba1),
        as.matrix(TabAab$Taba2),as.double(weix),as.integer(mwrn),sol=double(1),
        nit=integer(1),PACKAGE = "robustnegbin")
 if (abs(z$sol+999.0) < 1.e-3) z$sol <- NULL
 list(solution=z$sol, nit=z$nit) 
}



