glmrob.nb <- function(formula, data, start=NULL, method="glmrob.nb.fit", control=glmrob.nb.control(), model=TRUE, x=FALSE, y=TRUE, contrasts=NULL, init.dispersion=NULL, rep=2) {
  mf <- Call <- match.call()
  m <- match(c("formula", "data"), names(mf), 0)
  mf <- mf[c(1, m)]
  mf$drop.unused.levels <- TRUE
  mf[[1L]] <- quote(stats::model.frame)
  mf <- eval.parent(mf)
  Terms <- attr(mf, "terms")
  if (method == "model.frame") 
    return(mf)
  if (method != "glmrob.nb.fit")
    stop("The only method implemented is 'glmrob.nb.fit'")
  Y <- model.response(mf, "numeric")
  X <- if (!is.empty.model(Terms)) 
         model.matrix(Terms, mf, contrasts)
       else matrix(, NROW(Y), 0)
  int <- which(attr(X, "dimnames")[[2]]=="(Intercept)")
  if (length(int))
    X <- X[,-int,drop=FALSE] # remove intercept
  n <- length(Y)
  u <- runif(n)
  fit <- list()
  fit[[1]] <- glmrob.nb.fit(x=X, y=Y, u=u, start=start, control=control, init.dispersion=init.dispersion, final=TRUE)
  p <- length(fit[[1]]$start)
  if (rep > 2) {
    for (k in 2:rep) {
      u <- runif(n)
      fit[[k]] <- glmrob.nb.fit(x=X, y=Y, u=u, start=fit[[1]]$start, control=control, init.dispersion=fit[[1]]$init.dispersion, final=TRUE)
    }
    coefficients <- rowMeans(sapply(fit, function(z) z$coefficients))
    dispersion <- mean(sapply(fit, function(z) z$dispersion))
    s.err <- rowMeans(sapply(fit, function(z) z$s.err))
    varmat <- lapply(fit, function(z) z$cov)
    iter <- sapply(fit, function(z) z$iter)
  } else {
    coefficients <- fit[[1]]$coefficients
    dispersion <- fit[[1]]$dispersion
    s.err <- fit[[1]]$s.err
    varmat <- fit[[1]]$cov
    iter <- fit[[1]]$iter
  }
  result <- list()
  result$coefficients <- coefficients
  result$fitted.values <- exp(cbind(1,X)%*%coefficients)
  result$linear.predictors <- cbind(1,X)%*%coefficients
  result$dispersion <- dispersion
  result$s.err <- s.err[-length(s.err)]
  result$dispersion.s.err <- s.err[length(s.err)]  
  result$cov <- varmat
  result$iter <- iter
  result$terms <- Terms
  result$formula <- as.vector(attr(Terms, "formula"))
  if (model) 
    result$model <- mf
  if (x) 
    result$x <- X
  if (y) 
  result$y <- Y
  result$contrasts <- attr(X, "contrasts")
  result$xlevels <- .getXlevels(Terms, mf)
  result$control <- control
  result$method <- method
  result$call <- match.call()
  result$samplesize <- length(Y)
  result$fit <- fit
  result$rep <- rep
  class(result) <- "glmrob.nb"
  return(result)
}
