glmrob.nb.control <- function(MCML=list(csil=0.05, csiu=0.95, iterate=2, tol=1e-3, cutoff.adaptive=TRUE, gradient=FALSE, CoeffBound=9), M=list(mxT=300, tol=0.001, nint=10, verbose=FALSE, fortran=TRUE, ufact=1.1), MRC=list(nIterations=10, nAlternate=10, nGrid=25, tol=1e-06, standardize=FALSE)) {
  MCMLdefault <- list(csil=0.05, csiu=0.95, iterate=2, tol=1e-3, cutoff.adaptive=TRUE, gradient=FALSE, CoeffBound=9)
  Mdefault <- list(mxT=300, tol=0.001, nint=10, verbose=FALSE, fortran=TRUE, ufact=1.1)
  MRCdefault <- list(nIterations=10, nAlternate=10, nGrid=25, tol=1e-06, standardize=FALSE)
  MCML <- c(MCML, MCMLdefault[setdiff(names(MCMLdefault), names(MCML))])
  M <- c(M, Mdefault[setdiff(names(Mdefault), names(M))])
  MRC <- c(MRC, MRCdefault[setdiff(names(MRCdefault), names(MRC))])
  with(MCML,{
    if (!(is.numeric(csil) & length(csil)==1) || (csil < 0 | csil > 0.5)) {
      stop("'csil' must be a numeric scalar in the interval [0,0.5)") 
    }
    if (!(is.numeric(csiu) & length(csiu)==1) || (csiu <= 0.5 | csiu > 1)) {
      stop("'csil' must be a numeric scalar in the interval (0.5,1]") 
    }
    if (!is.numeric(iterate) || iterate!=as.integer(iterate)) {
      stop("'iterate' must be numeric and integer")
    }
    if (!is.numeric(tol) || tol <= 0) {
      stop("'tol' must be numeric and non negative")
    }
    if (!is.logical(cutoff.adaptive)) {
      stop("'cutoff.adaptive' must be a logical")
    }
    if (!is.logical(gradient)) {
      stop("'gradient' must be a logical")
    }
    if (!is.numeric(CoeffBound) || length(CoeffBound)!=1 || CoeffBound <=0) {
      stop("'CoeffBound' must be a scalar positive numeric value")
    }
  })
  with(M,{
    if (!is.numeric(mxT) || mxT <= 0) {
      stop("'mxT' must be numeric and positive")
    }
    if (!is.numeric(tol) || tol <= 0) {
      stop("'tol' must be numeric and positive")
    }
    if (!is.numeric(nint) || nint!=as.integer(nint)) {
      stop("'nint' must be numeric and integer")
    }
    if (!is.logical(verbose)) {
      stop("'verbose' must be a logical")
    }
    if (!is.logical(fortran)) {
      stop("'fortran' must be a logical")
    }
    if (!is.numeric(ufact) || ufact <= 0) {
      stop("'ufact' must be numeric and positive")
    }
  })
  with(MRC,{
    if (!is.numeric(nIterations) || nIterations!=as.integer(nIterations)) {
      stop("'nIterations' must be numeric and integer")
    }
    if (!is.numeric(nAlternate) || nAlternate!=as.integer(nAlternate)) {
      stop("'nAlternate' must be numeric and integer")
    }
    if (!is.numeric(nGrid) || nGrid!=as.integer(nGrid)) {
      stop("'nGrid' must be numeric and integer")
    }
    if (!is.numeric(tol) || tol <= 0) {
      stop("'tol' must be numeric and positive")
    }
    if (!is.logical(standardize)) {
      stop("'standardize' must be a logical")
    }
  })
  list(MCML=MCML, M=M, MRC=MRC)
}
