glmrob.nb.fit <- function(x, y, u=runif(length(y)), start=NULL, control=glmrob.nb.control(), init.dispersion=NULL, final=TRUE) {
  p <- ncol(x)
  nIter <- control$MRC$nIterations
  nAlter <- control$MRC$nAlternate
  nGrid <- control$MRC$nGrid
  tolMRC <- control$MRC$tol
  stnMRC <- control$MRC$standardize
#
  Table <- robustnegbin::M_Table_80
  alpha1 <- Table$alpha1
  alpha2 <- Table$alpha2
  mxtM <- control$M$mxt
  tolM <- control$M$tol
  nintM <- control$M$nint
  verbM <- control$M$verbose
  FortM <- control$M$fortran
  ufact <- control$M$ufact
#
  csil <- control$MCML$csil
  csiu <- control$MCML$csiu
  iterate <- control$MCML$iterate
  tolMCML <- control$MCML$tol
  cutoff.adaptive <- control$MCML$cutoff.adaptive
  gradient <- control$MCML$gradient
  CoeffBnd <- control$MCML$CoeffBound
#
  init <- fin <- sde1 <- sde2 <- NULL
  BetaC <- alphaC <- NULL
#
  if (is.null(start) | is.null(init.dispersion)) {
    if (is.null(start)) {
# Initial estimate: (a) Maximum Rank Correlation of slopes
      Q <- maxCorGrid(x, y, method="kendall", standardize=stnMRC, nIterations=nIter, nAlternate=nAlter, nGrid=nGrid, tol=tolMRC)
      betb <- Q$a
    } else {
      betb <- start[-1] ##remove intercept
    }
    zz <- t(betb%*%t(x))
# Initial estimate (b): Estimate of intercept, slope-norm, and dispersion
    wz <- uw.hard(zz,b=2)
    zr <- zz[wz==1]
    yr <- y[wz==1]
    nr <- sum(wz)
    ctrl <- cubinf.control(ufact)
    CBF <- cubinf(cbind(1,zr), yr, family=poisson(), null.dev = FALSE, control=ctrl)
    BetaP <- drop(CBF$coeff)
    if (is.null(init.dispersion)) {
      init.dispersion <- MestimateAlpha(zr, yr, BetaP[2:1], alp.low=alpha1, alp.up=alpha2, TabAab=Table, tol=tolM, maxit=mxtM, nint=nintM, verbose=verbM, Fortran=FortM)$alpha0
    }
    if (is.null(start)) {
      obj.initial <- MCML(as.matrix(zz), y, u, BetaP, init.dispersion, csil=csil, csiu=csiu, iterate=0, tol=tolMCML, CoeffBound=CoeffBnd, cutoff.adaptive=cutoff.adaptive, gradient=gradient)
      init.dispersion <- obj.initial$alpha
      start <- c(obj.initial$Beta[1], obj.initial$Beta[2]*betb)
    } else {
      obj.initial <- NULL
    }
  } else {
    obj.initial <- NULL
  } # end initial
  if (final) {
    obj.final <- MCML(x, y, u, start, init.dispersion, csil=csil, csiu=csiu, iterate=iterate, tol=tolMCML, CoeffBound=CoeffBnd, cutoff.adaptive=cutoff.adaptive, gradient=gradient)
    BetaC <- obj.final$Beta
    alphaC <- obj.final$alpha 
# Standard errors
    n <- length(y)
    Tax <- obj.final$Tax
    Tbx <- obj.final$Tbx
    tax <- obj.final$tax
    tbx <- obj.final$tbx
    InfC1 <- InfoML(BetaC, alphaC, x, gam=1e-7)
    varcov <- solve(InfC1)/n
    se <- sqrt(diag(varcov))
###  InfC2 <- InfoMCML(BetaC, alphaC, x, Tax, Tbx, tax, tbx, gam=1e-7)
###  sde2 <- sqrt(diag(solve(InfC2))/n)
    result <- list(coefficients=BetaC, dispersion=alphaC, s.err=se, cov=varcov, a=obj.final$a, b=obj.final$b, start=start, init.dispersion=init.dispersion, iter=obj.final$nit, obj.initial=obj.initial, obj.final=obj.final)
  } else {
    InfC1 <- InfoML(start, init.dispersion, x, gam=1e-7)
    varcov <- solve(InfC1)/n
    se <- sqrt(diag(varcov))
    result <- list(coefficients=start, dispersion=init.dispersion, s.err=se, cov=varcov, a=NA, b=NA, start=start, init.dispersion=init.dispersion, iter=NA, obj.initial=obj.initial, obj.final=NA)
  }
}

