summary.glmrob.nb <- function (object, correlation = FALSE, symbolic.cor = FALSE, ...) {
  dispersion <- object$dispersion
  if (is.null(dispersion)) {
    dispersion <- 1
    dispersion.s.err <- 0
  } else {
    dispersion.s.err <- object$dispersion.s.err
  }
  coefs <- object$coefficients
  aliased <- is.na(coefs)
  if (any(aliased)) 
    coefs <- coefs[!aliased]
  covmat <- object$cov
  s.err <- object$s.err
  zvalue <- coefs/s.err
  pvalue <- 2 * pnorm(-abs(zvalue))
  coef.table <- cbind(Estimate=coefs, `Std. Error`=s.err, `z value` = zvalue, `Pr(>|z|)` = pvalue)
  ans <- c(object[c("call", "terms", "family", "iter", "control", 
        "method", "residuals", "fitted.values", "w.r", "w.x")], 
  list(deviance = NULL, df.residual = NULL, null.deviance = NULL, 
    df.null = NULL, df = NULL, aliased = aliased, coefficients = coef.table, 
    dispersion = dispersion, dispersion.s.err=dispersion.s.err, rep=object$rep, samplesize=object$samplesize, cov.scaled = covmat))
  if (correlation) {
    ans$correlation <- if (is.list(covmat)) {
      Cor <- lapply(covmat, cov2cor)
      cortemp <- Cor[[1]]
      for (j in 2:length(Cor)) {
        cortemp <- cortemp + Cor[[j]]
      }
      cortemp/length(Cor)
    } else {
      cov2cor(covmat)
    }
    ans$symbolic.cor <- symbolic.cor
  }
  structure(ans, class = "summary.glmrob.nb")
}
