\name{glmrob.nb}
\alias{glmrob.nb}
\title{
  Fit a Negative Binomial Generalized Linear Model using Robust Method
}
\description{
  \code{glmrob.nb} is used to fit Negative Binomial generalized
     linear models by the Modified Conditional Maximum
     Likelihood robust method. The models are specified by
     giving a symbolic description of the linear predictor.
}
\usage{
glmrob.nb(formula, data, start = NULL, method = "glmrob.nb.fit",
  control = glmrob.nb.control(), model = TRUE, x = FALSE, y = TRUE,
  contrasts = NULL, init.dispersion = NULL, rep = 2)
}
\arguments{
  \item{formula}{
    a \code{\link{formula}}, i.e., a symbolic description of the model to be
    fit (cf. \code{\link{glm}} or \code{\link{lm}}).
  }
  \item{data}{
    an optional data frame containing the variables in the model.
    If not found in \code{data}, the variables are taken from
    \code{environment(formula)}, typically the environment from which
    \code{glmrob.nb} is called.
  }
  \item{start}{
    starting values for the parameters in the linear predictor.
  }
  \item{method}{
    a character string specifying the robust fitting method.
    The only method available at the moment is \code{\link{glmrob.nb.fit}}.
  }
  \item{control}{
    a list of parameters for controlling the fitting process.
    See the documentation for \code{\link{glmrob.nb.control}} for details.
  }
  \item{model}{
    a logical value indicating whether model frame should be
    included as a component of the returned value.
  }
  \item{x, y}{
    logical values indicating whether the response vector and
    model matrix used in the fitting process should be returned
    as components of the returned value.
  }
  \item{contrasts}{
     an optional list. See the \code{contrasts.arg} of
     \code{\link{model.matrix.default}}.
  }
  \item{init.dispersion}{
     optional initial value for the dispersion parameter.
  }
  \item{rep}{
     number of times the \code{\link{glmrob.nb.fit}} function is called.
     Results will be averaged.
  }
}
\details{
  The intercept is always considered in the design matrix
  and it is inserted as the first coefficient.

  The \code{dispersion} parameter is \code{1/theta} parameter in the function
  \code{\link[MASS]{glm.nb}}.  
}    
\value{
  A fitted model object of class \code{glmrob.nb}. The object is like the
  output of \code{glmrob} and \code{lmrob} and contains the following
  components, 
  \item{coefficients}{a named vector of coefficients.}
  \item{fitted.values}{the fitted mean values, obtained by transforming
    the linear predictors by the inverse of the link function.}
  \item{linear.predictors}{the linear fit on link scale.}
  \item{dispersion}{estimation of the dispersion parameter.}
  \item{s.err}{the standard error for the coefficients.}
  \item{dispersion.s.err}{the standard error for the dispersion parameter.}
  \item{cov}{the estimated asymptotic covariance matrix of the estimated
    coefficients and dispersion (last row/column).}
  \item{iter}{(average) number of iterations.}
  \item{terms}{the \code{terms} object used.}
  \item{model}{if requested (the default), the model frame.}
  \item{y,x}{if requested, the response used and/or the model matrix used.}
  \item{xlevels}{(where relevant) a record of the levels of the factors
    used in fitting.}
  \item{control}{the value of the \code{control} argument used.}
  \item{method}{the name of the robust fitter function used.}
  \item{call}{the matched call.}
  \item{samplesize}{the sample size.}
  \item{fit}{a list equals to \code{rep} with objects from running
    \code{rep} times the fitter \code{\link{glmrob.nb.fit}} with
    different \code{u} argument.}
  \item{rep}{number of replications.}
}
\references{
  Marazzi A., Valdora M., Yohai V., Amiguet M. (2018).
  A robust conditional maximum likelihood estimator for
  generalized linear models with a dispersion parameter.
  Submitted
}
\author{
  C. Agostinelli and A. Marazzi
}
\seealso{
  \code{\link{glmrob.nb.fit}}, \code{\link{glmrob.nb.control}}, \code{\link{glm.nb}}.  
}
\examples{
  data(polytrauma)
  p <- glmrob.nb(I(LOS-1)~Nbdg+Nbtt+Age+I(Sex-1)+Age*I(Sex-1), data=polytrauma)
  summary(p)
}
\keyword{robust}
\keyword{regression}
\keyword{nonlinear}
  