\name{glmrob.nb.control}
\alias{glmrob.nb.control}
\title{Control parameters for the glmrob.nb function}
\description{Control parameters for the glmrob.nb function. 
  The parameters are collected in three lists:
    MCML: control parameters for the computation of the modified CML estimate
    M:    control parameters for the computation of the M estimate of alpha
    MRC:  control parameters of the function maxCorGrid from package ccaPP
}
\usage{
glmrob.nb.control(
  MCML = list(csil=0.05, csiu=0.95, iterate=2, tol=0.001,
    cutoff.adaptive=TRUE, gradient=FALSE, CoeffBound = 9), 
  M = list(mxT=300, tol=0.001, nint=10, verbose=FALSE, fortran=TRUE,
    ufact = 1.1), 
  MRC = list(nIterations=10, nAlternate=10, nGrid=25, tol=1e-06,
    standardize=FALSE))   
}
\arguments{
\item{MCML}{
  csil: maximal lower rejection fraction for the randomized quantile residuals;
  csiu: maximal upper rejection fraction for the randomized quantile residuals;
  iterate: number of iterations of the modified CML estimate.
    Set \code{iterate=0} if no iteration is desired.
  tol: tolerance in CML iterations
  cutoff.adaptive: if \code{cutoff.adaptive=TRUE}, the adaptive cutoff
    procedure is used; else, fixed cutoffs are used;
  gradient: if \code{gradient=TRUE}, the gradient is computed with the
    help of a special function. If \code{gradient=FALSE} the numerical
    approximation provided by the R function optim is used.
  CoeffBound: if the function \code{optim} returns a coefficient estimate
    which is larger than \code{CoeffBound} or smaller than \code{-CoeffBound}, 
    the initial value is used in place of the returned value and a warning
    is given.
}
\item{M}{
  mxT: maximum number if iterations of a regula falsi algorithm;
  tol: tolerance for the regula falsi algorithm;
  nint: the interval for searching the best \code{dispersion} is divided into
    \code{nint} subintervals to determine a starting value of the regula
    falsi algorithm;
  verbose: if \code{verbose=TRUE} a monitoring of the iterations is provided;
  fortran: if \code{fortran=FALSE}, a R code is used; if \code{fortran=TRUE},
    a fortran code is used;
  ufact: tuning constant of the conditionally unbiased bounded influence
    estimates in function \code{cubinf.control} of package \code{robcbi} 
}
\item{MRC}{
  see function \code{maxCorGrid} from package \code{ccaPP}.
}
}
\value{
  A list containing three lists as in the input.  
}
\references{
  Marazzi A., Valdora M., Yohai V., Amiguet M. (2018).
  A robust conditional maximum likelihood estimator for
  generalized linear models with a dispersion parameter.
  Submitted
}
\author{
  C. Agostinelli and A. Marazzi
}

\examples{
  # set the value of the iterate parameter to 100
  # all the other values leave unchanged to the default value
  control <- glmrob.nb.control(MCML=list(iterate=100))
}

\keyword{robust}
\keyword{regression}
\keyword{nonlinear}
