\name{glmrob.nb.fit}
\alias{glmrob.nb.fit}
\title{
  Workhorse for fitting a Negative Binomial Generalized Linear Model
  using Robust Method
}
\description{
    \code{glmrob.nb.fit} is the workhorse used to fit Negative Binomial
     generalized linear models by the Modified Conditional Maximum
     Likelihood robust method.  
}
\usage{
glmrob.nb.fit(x, y, u = runif(length(y)), start = NULL,
  control = glmrob.nb.control(), init.dispersion = NULL, final = TRUE)
}
\arguments{
  \item{x}{
    a design matrix.
  }
  \item{y}{
    a vector of observations.
  }
  \item{u}{
    a vector from a uniform distribution in [0,1] with the same
    length of \code{y}
  }
  \item{start}{
    starting values for the parameters in the linear predictor.    
  }
  \item{control}{
    a list of parameters for controlling the fitting process.
    See the documentation for \code{\link{glmrob.nb.control}} for details.
  }
  \item{init.dispersion}{
     optional initial value for the dispersion parameter.
  }
  \item{final}{
     if \code{final=FALSE} only initial values are computed.
  }
}
\details{
  The intercept is always included automatically in the design matrix
  as the first column.

  The \code{dispersion} parameter is \code{1/theta} parameter in the function
  \code{\link[MASS]{glm.nb}}.
}
\value{
  A list with the following components
  \item{coefficients}{a named vector of coefficients.}
  \item{dispersion}{estimation of dispersion parameter.}
  \item{s.err}{the standard error for the coefficients and the
    dispersion (last value) parameters.}
  \item{cov}{the estimated asymptotic covariance matrix of the estimated
    coefficients and dispersion (last row/column).}
  \item{a}{lower cutoff.}
  \item{b}{upper cutoff.}  
  \item{start}{the initial values used for the coefficients.}
  \item{init.dispersion}{the initial value used for the dispersion parameter.}
  \item{iter}{if \code{final=TRUE} number of iterations otherwise \code{NA}.}
  \item{obj.initial}{internal object from the initial step.}
  \item{obj.final}{if \code{final=TRUE} then internal object from the final step is reported otherwise \code{NA}.}
}
\references{
  Marazzi A., Valdora M., Yohai V., Amiguet M. (2018).
  A robust conditional maximum likelihood estimator for
  generalized linear models with a dispersion parameter.
  Submitted
}
\author{
  C. Agostinelli and A. Marazzi
}
  
\seealso{
\code{\link{glmrob.nb}}
}

\keyword{robust}
\keyword{regression}
\keyword{nonlinear}
  